nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Ahbmatprio

Struct Ahbmatprio 

#[repr(transparent)]
pub struct Ahbmatprio(pub u32);
AHB Matrix Priority Control

Tuple Fields

0: u32

Implementations

Source

impl Ahbmatprio

pub const fn pri_cpu0_cbus(&self) -> PriCpu0Cbus

CPU0 C-AHB bus master priority level

pub const fn set_pri_cpu0_cbus(&mut self, val: PriCpu0Cbus)

CPU0 C-AHB bus master priority level

pub const fn pri_cpu0_sbus(&self) -> PriCpu0Sbus

CPU0 S-AHB bus master priority level

pub const fn set_pri_cpu0_sbus(&mut self, val: PriCpu0Sbus)

CPU0 S-AHB bus master priority level

pub const fn pri_cpu1_sbus_smart_dma_d(&self) -> PriCpu1SbusSmartDmaD

CPU1 S-AHB/SmartDMA-D bus master priority level

pub const fn set_pri_cpu1_sbus_smart_dma_d(&mut self, val: PriCpu1SbusSmartDmaD)

CPU1 S-AHB/SmartDMA-D bus master priority level

pub const fn pri_cpu1_cbus_smart_dma_i(&self) -> PriCpu1CbusSmartDmaI

CPU1 C-AHB/SmartDMA-I bus master priority level

pub const fn set_pri_cpu1_cbus_smart_dma_i(&mut self, val: PriCpu1CbusSmartDmaI)

CPU1 C-AHB/SmartDMA-I bus master priority level

pub const fn dma0(&self) -> AhbmatprioDma0

DMA0 controller bus master priority level

pub const fn set_dma0(&mut self, val: AhbmatprioDma0)

DMA0 controller bus master priority level

pub const fn dma1(&self) -> AhbmatprioDma1

DMA1 controller bus master priority level

pub const fn set_dma1(&mut self, val: AhbmatprioDma1)

DMA1 controller bus master priority level

pub const fn pri_pkc_els(&self) -> PriPkcEls

PKC and ELS bus master priority level

pub const fn set_pri_pkc_els(&mut self, val: PriPkcEls)

PKC and ELS bus master priority level

pub const fn pri_npu_pq(&self) -> PriNpuPq

NPU O bus and Powerquad bus master priority level

pub const fn set_pri_npu_pq(&mut self, val: PriNpuPq)

NPU O bus and Powerquad bus master priority level

pub const fn pri_coolflux_i(&self) -> PriCoolfluxI

CoolFlux I bus master priority level

pub const fn set_pri_coolflux_i(&mut self, val: PriCoolfluxI)

CoolFlux I bus master priority level

pub const fn pri_coolflux_x(&self) -> PriCoolfluxX

CoolFlux X bus master priority level

pub const fn set_pri_coolflux_x(&mut self, val: PriCoolfluxX)

CoolFlux X bus master priority level

pub const fn pri_coolflux_y_espi(&self) -> PriCoolfluxYEspi

CoolFlux Y bus master priority level

pub const fn set_pri_coolflux_y_espi(&mut self, val: PriCoolfluxYEspi)

CoolFlux Y bus master priority level

pub const fn pri_npu_d(&self) -> PriNpuD

NPU D bus master priority level

pub const fn set_pri_npu_d(&mut self, val: PriNpuD)

NPU D bus master priority level

pub const fn pri_usb_fs_enet(&self) -> PriUsbFsEnet

USB-FS and ENET bus master priority level

pub const fn set_pri_usb_fs_enet(&mut self, val: PriUsbFsEnet)

USB-FS and ENET bus master priority level

pub const fn pri_usb_hs(&self) -> PriUsbHs

USB-HS bus master priority level

pub const fn set_pri_usb_hs(&mut self, val: PriUsbHs)

USB-HS bus master priority level

pub const fn pri_usdhc(&self) -> PriUsdhc

USDHC bus master priority level

pub const fn set_pri_usdhc(&mut self, val: PriUsdhc)

USDHC bus master priority level