#[repr(transparent)]pub struct Cpu0stckcal(pub u32);Expand description
Secure CPU0 System Tick Calibration
Tuple Fields
0: u32Implementations
Sourceimpl Cpu0stckcal
impl Cpu0stckcal
Sourcepub const fn tenms(&self) -> u32
pub const fn tenms(&self) -> u32
Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn set_tenms(&mut self, val: u32)
pub const fn set_tenms(&mut self, val: u32)
Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn skew(&self) -> Cpu0stckcalSkew
pub const fn skew(&self) -> Cpu0stckcalSkew
Whether the TENMS value is exact.
Sourcepub const fn set_skew(&mut self, val: Cpu0stckcalSkew)
pub const fn set_skew(&mut self, val: Cpu0stckcalSkew)
Whether the TENMS value is exact.
Sourcepub const fn noref(&self) -> Cpu0stckcalNoref
pub const fn noref(&self) -> Cpu0stckcalNoref
Whether the device provides a reference clock to the processor.
Sourcepub const fn set_noref(&mut self, val: Cpu0stckcalNoref)
pub const fn set_noref(&mut self, val: Cpu0stckcalNoref)
Whether the device provides a reference clock to the processor.