nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

ElsAsBootLog0

Struct ElsAsBootLog0 

#[repr(transparent)]
pub struct ElsAsBootLog0(pub u32);
Boot state captured during boot: Main ROM log

Tuple Fields

0: u32

Implementations

Source

impl ElsAsBootLog0

pub const fn boot_image(&self) -> BootImage

Boot image source used during this boot.

pub const fn set_boot_image(&mut self, val: BootImage)

Boot image source used during this boot.

pub const fn cmac(&self) -> bool

CMAC verify is used instead of ECDSA verify on this boot.

pub const fn set_cmac(&mut self, val: bool)

CMAC verify is used instead of ECDSA verify on this boot.

pub const fn ecdsa(&self) -> bool

ECDSA P-384 verification is done on this boot.

pub const fn set_ecdsa(&mut self, val: bool)

ECDSA P-384 verification is done on this boot.

pub const fn off_chip(&self) -> bool

Off-chip Prince is enabled during boot.

pub const fn set_off_chip(&mut self, val: bool)

Off-chip Prince is enabled during boot.

pub const fn on_chip(&self) -> bool

On-chip Prince is enabled during boot.

pub const fn set_on_chip(&mut self, val: bool)

On-chip Prince is enabled during boot.

pub const fn cdi_csr(&self) -> bool

CDI based device keys are derived for CSR harvesting on this boot.

pub const fn set_cdi_csr(&mut self, val: bool)

CDI based device keys are derived for CSR harvesting on this boot.

pub const fn cdi_dice(&self) -> bool

CDI per DICE specification is computed on this boot.

pub const fn set_cdi_dice(&mut self, val: bool)

CDI per DICE specification is computed on this boot.

pub const fn trustzone(&self) -> bool

TrustZone preset data is loaded during this boot.

pub const fn set_trustzone(&mut self, val: bool)

TrustZone preset data is loaded during this boot.

pub const fn debug_auth(&self) -> bool

Debug authentication done in this session prior to boot.

pub const fn set_debug_auth(&mut self, val: bool)

Debug authentication done in this session prior to boot.

pub const fn itrc(&self) -> bool

ITRC zeroize event is handled in this session of boot.

pub const fn set_itrc(&mut self, val: bool)

ITRC zeroize event is handled in this session of boot.

pub const fn dig_gdet(&self) -> bool

Digital glitch detector is enabled during boot.

pub const fn set_dig_gdet(&mut self, val: bool)

Digital glitch detector is enabled during boot.

pub const fn ana_gdet(&self) -> bool

Analog glitch detector is enabled during boot.

pub const fn set_ana_gdet(&mut self, val: bool)

Analog glitch detector is enabled during boot.

pub const fn deep_pd(&self) -> bool

Boot from deep-power down state.

pub const fn set_deep_pd(&mut self, val: bool)

Boot from deep-power down state.

pub const fn low_power(&self) -> u8

Last low-power mode value. ROM copies SPC_LP_MODE field from SPC->SC[7:4].

pub const fn set_low_power(&mut self, val: u8)

Last low-power mode value. ROM copies SPC_LP_MODE field from SPC->SC[7:4].

pub const fn isp(&self) -> bool

ISP pin state at boot time. ROM copies CMC->MR0[0].

pub const fn set_isp(&mut self, val: bool)

ISP pin state at boot time. ROM copies CMC->MR0[0].