nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

ElsAssetProt

Struct ElsAssetProt 

#[repr(transparent)]
pub struct ElsAssetProt(pub u32);
ELS Asset Protection Register

Tuple Fields

0: u32

Implementations

Source

impl ElsAssetProt

pub const fn asset_protection(&self) -> AssetProtection

ELS asset protection. This field controls the asset protection port to the ELS module. Refer to the ELS chapter in the SRM for more details.

pub const fn set_asset_protection(&mut self, val: AssetProtection)

ELS asset protection. This field controls the asset protection port to the ELS module. Refer to the ELS chapter in the SRM for more details.